The faultdiagnosistoolbox package
=================================

.. module:: faultdiagnosistoolbox

.. autoclass:: DiagnosisModel
   :members: 

.. automodule:: faultdiagnosistoolbox.dmperm
   :members: srank, GetDMParts

.. automodule:: faultdiagnosistoolbox.MHS
   :members: 

.. automodule:: faultdiagnosistoolbox.diag_util
   :members: IsolabilityMatrix, DiagnosesAndConfusionMatrix, PlotConfusionMatrix

.. automodule:: faultdiagnosistoolbox.testselection_rf
   :members:

